@@ -329,6 +329,10 @@ class NsxV3RESTClientTestCase(nsxlib_testcase.NsxClientTestCase):
                                              500157, [777, 500045])
         self.assertEqual(exc, nsxlib_exc.NsxPendingDelete)
 
+        code = requests.codes.SERVICE_UNAVAILABLE
+        exc = client.http_error_to_exception(code, None)
+        self.assertEqual(exc, nsxlib_exc.ServiceUnavailable)
+
 
 class NsxV3JSONClientTestCase(nsxlib_testcase.NsxClientTestCase):
 
