@@ -416,6 +416,24 @@ class ClusteredAPITestCase(nsxlib_testcase.NsxClientTestCase):
         # This exception does not ground endpoint
         self.assertEqual(cluster.ClusterHealth.GREEN, api.health)
 
+    def test_max_retry_attempts_on_none_json_error(self):
+        # handle response not json format
+        def server1_error():
+            return mocks.MockRequestsResponse(
+                codes.SERVICE_UNAVAILABLE,
+                "python-requests/2.27.1 d50561a7-7540-4342-88e3-c235e587a19")
+
+        conf_managers = ['8.9.10.11', '9.10.11.12', '10.11.12.13']
+        max_attempts = 2
+        api = self.mock_nsx_clustered_api(
+            nsx_api_managers=conf_managers,
+            max_attempts=max_attempts,
+            session_response=[server1_error for i in range(0, max_attempts)])
+
+        self.assertRaises(nsxlib_exc.ServiceUnavailable,
+                          api.get, 'api/v1/transport-zones')
+        self.assertEqual(cluster.ClusterHealth.GREEN, api.health)
+
     def test_regenerate_error(self):
 
         def server_error():
@@ -436,6 +454,25 @@ class ClusteredAPITestCase(nsxlib_testcase.NsxClientTestCase):
                           api.get, 'api/v1/transport-zones')
         self.assertEqual(cluster.ClusterHealth.GREEN, api.health)
 
+    def test_xsrf_token_error(self):
+        def server_error():
+            return mocks.MockRequestsResponse(
+                codes.FORBIDDEN,
+                jsonutils.dumps({'error_message': 'test', 'error_code': 98}))
+
+        conf_managers = ['8.9.10.11', '9.10.11.12', '10.11.12.13']
+        exceptions = config.ExceptionConfig()
+        max_attempts = 2
+        api = self.mock_nsx_clustered_api(
+            nsx_api_managers=conf_managers,
+            max_attempts=max_attempts,
+            session_response=[server_error for i in range(0, max_attempts)])
+        api.nsxlib_config.exception_config = exceptions
+
+        self.assertRaises(nsxlib_exc.BadXSRFToken,
+                          api.get, 'api/v1/transport-zones')
+        self.assertEqual(cluster.ClusterHealth.GREEN, api.health)
+
     def test_exception_translation_on_ground_error(self):
 
         def server_error():
