@@ -242,6 +242,24 @@ class TestRouter(nsxlib_testcase.NsxClientTestCase):
                 tags=None,
                 display_name=None)
 
+    def test_add_gw_snat_rule_fw_match(self):
+        logical_router_id = test_constants.FAKE_ROUTER_UUID
+        gw_ip = '1.1.1.1'
+        with mock.patch.object(self.nsxlib.router.nsxlib.logical_router,
+                               'add_nat_rule') as add_api:
+            self.nsxlib.router.add_gw_snat_rule(
+                logical_router_id, gw_ip,
+                firewall_match=nsx_constants.NAT_FIREWALL_MATCH_EXTERNAL)
+            add_api.assert_called_with(
+                logical_router_id,
+                translated_network=gw_ip,
+                action="SNAT",
+                firewall_match=nsx_constants.NAT_FIREWALL_MATCH_EXTERNAL,
+                source_net=None,
+                rule_priority=nsx_router.GW_NAT_PRI,
+                tags=None,
+                display_name=None)
+
     def test_update_router_edge_cluster(self):
         logical_router_id = test_constants.FAKE_ROUTER_UUID
         ec_id = test_constants.FAKE_EDGE_CLUSTER
@@ -299,6 +317,15 @@ class TestRouter(nsxlib_testcase.NsxClientTestCase):
                 '1.1.1.1', '2.2.2.2')
             self.assertEqual(add_rule.call_count, 2)
 
+    def test_add_fip_nat_rules_firewall_match(self):
+        with mock.patch.object(self.nsxlib.logical_router,
+                               "add_nat_rule") as add_rule:
+            self.nsxlib.router.add_fip_nat_rules(
+                test_constants.FAKE_ROUTER_UUID,
+                '1.1.1.1', '2.2.2.2',
+                firewall_match=nsx_constants.NAT_FIREWALL_MATCH_EXTERNAL)
+            self.assertEqual(add_rule.call_count, 2)
+
     def test_delete_fip_nat_rules(self):
         with mock.patch.object(self.nsxlib.logical_router,
                                "delete_nat_rule_by_values") as del_rule:
