@@ -118,43 +118,21 @@ class NsxLib(lib.NsxLibBase):
         self.tag_limits = self.get_tag_limits()
         utils.update_tag_limits(self.tag_limits)
 
-    @property
-    def keepalive_section(self):
-        return 'transport-zones'
-
     @property
     def validate_connection_method(self):
         """Return a method that will validate the NSX manager status"""
-        def check_manager_status_v1(client, manager_url):
-            """MP healthcheck for Version 2.3 and below"""
-            # Try to get the cluster status silently and with no retries
-            status = client.get('operational/application/status',
-                                silent=True, with_retries=False)
-            if (not status or status.get('application_status') != 'WORKING'):
-                msg = _("Manager is not in working state: %s") % status
-                LOG.warning(msg)
-                raise exceptions.ResourceNotFound(
-                    manager=manager_url, operation=msg)
 
-        def check_manager_status_v2(client, manager_url):
+        def check_manager_status(client, manager_url):
             """MP healthcheck for Version 2.4 and above"""
             # Try to get the status silently and with no retries
             status = client.get('reverse-proxy/node/health',
                                 silent=True, with_retries=False)
-            if (not status or not status.get('healthy', False)):
+            if not status or not status.get('healthy', False):
                 msg = _("Manager is not in working state: %s") % status
                 LOG.warning(msg)
                 raise exceptions.ResourceNotFound(
                     manager=manager_url, operation=msg)
 
-        def check_manager_status(client, manager_url):
-            # Decide on the healthcheck by the version (if already initialized)
-            if (self.nsx_version and
-                version.LooseVersion(self.nsx_version) >=
-                version.LooseVersion(nsx_constants.NSX_VERSION_2_4_0)):
-                return check_manager_status_v2(client, manager_url)
-            return check_manager_status_v1(client, manager_url)
-
         return check_manager_status
 
     def get_version(self):
@@ -170,6 +148,14 @@ class NsxLib(lib.NsxLibBase):
         return node.get('export_type') == 'RESTRICTED'
 
     def feature_supported(self, feature):
+        if (version.LooseVersion(self.get_version()) >=
+            version.LooseVersion(nsx_constants.NSX_VERSION_3_1_0)):
+            # features available since 3.1.0
+            if feature == nsx_constants.FEATURE_MP2P_MIGRATION:
+                return True
+            if feature == nsx_constants.FEATURE_SPOOFGUARD_CIDR:
+                return True
+
         if (version.LooseVersion(self.get_version()) >=
             version.LooseVersion(nsx_constants.NSX_VERSION_3_0_0)):
             # features available since 3.0.0
