@@ -17,21 +17,36 @@ import re
 import time
 from urllib import parse as urlparse
 
+try:
+    from simplejson.errors import JSONDecodeError
+except ImportError:
+    from json.decoder import JSONDecodeError
+
 from oslo_log import log
 from oslo_serialization import jsonutils
 import requests
 
 from vmware_nsxlib._i18n import _
+from vmware_nsxlib.v3 import constants
 from vmware_nsxlib.v3 import exceptions
 from vmware_nsxlib.v3 import utils
-
 LOG = log.getLogger(__name__)
 
 NULL_CURSOR_PREFIX = '0000'
 
 
 def get_http_error_details(response):
-    msg = response.json() if response.content else ''
+    try:
+        msg = response.json() if response.content else ''
+    except JSONDecodeError as e:
+        LOG.debug("decode response %s error %s", response.content, e)
+        # error_code can't be None else it can't be casted to an exception
+        return {'status_code': response.status_code,
+                'error_code': response.status_code,
+                'related_error_codes': [],
+                'related_status_codes': [],
+                'details': response.content}
+
     error_code = None
     related_error_codes = []
     related_status_codes = []
@@ -47,7 +62,10 @@ def get_http_error_details(response):
                                 for error in msg.get('related_errors', []) if
                                 error.get('httpStatus')]
 
+        details = msg.get('details')
         msg = msg['error_message']
+        if details:
+            msg += " details: %s" % details
         if related_errors:
             msg += " relatedErrors: %s" % ' '.join(related_errors)
 
@@ -85,6 +103,7 @@ def http_error_to_exception(status_code, error_code, related_error_codes=None):
             {'60508': exceptions.NsxIndexingInProgress,
              '60514': exceptions.NsxSearchTimeout,
              '60515': exceptions.NsxSearchOutOfSync,
+             '60576': exceptions.NsxSearchPipelineError,
              '8327': exceptions.NsxOverlapVlan,
              '500045': exceptions.NsxPendingDelete,
              '500030': exceptions.ResourceInUse,
@@ -170,9 +189,10 @@ class RESTClient(object):
                             expected_results=expected_results)
 
     def create(self, resource='', body=None, headers=None,
-               expected_results=None):
+               expected_results=None, retry_confirm=False):
         return self.url_post(resource, body, headers=headers,
-                             expected_results=expected_results)
+                             expected_results=expected_results,
+                             retry_confirm=retry_confirm)
 
     def patch(self, resource='', body=None, headers=None):
         return self.url_patch(resource, body, headers=headers)
@@ -202,9 +222,11 @@ class RESTClient(object):
         return self._rest_call(url, method='PUT', body=body, headers=headers,
                                expected_results=expected_results)
 
-    def url_post(self, url, body, headers=None, expected_results=None):
+    def url_post(self, url, body, headers=None, expected_results=None,
+                 retry_confirm=False):
         return self._rest_call(url, method='POST', body=body, headers=headers,
-                               expected_results=expected_results)
+                               expected_results=expected_results,
+                               retry_confirm=retry_confirm)
 
     def url_patch(self, url, body, headers=None):
         return self._rest_call(url, method='PATCH', body=body, headers=headers)
@@ -265,6 +287,7 @@ class RESTClient(object):
                    silent=False, expected_results=None, **kwargs):
         request_headers = headers.copy() if headers else {}
         request_headers.update(self._default_headers)
+        retry_confirm = kwargs.pop(constants.API_RETRY_CONFIRM, False)
 
         if utils.INJECT_HEADERS_CALLBACK:
             inject_headers = utils.INJECT_HEADERS_CALLBACK()
@@ -278,7 +301,8 @@ class RESTClient(object):
         result = do_request(
             request_url,
             data=body,
-            headers=request_headers)
+            headers=request_headers,
+            retry_confirm=retry_confirm)
         te = time.time()
         if silent:
             self._conn.set_silent(False)
