@@ -104,15 +104,23 @@ class TimeoutSession(requests.Session):
     # wrapper timeouts at the session level
     # see: https://goo.gl/xNk7aM
     def request(self, *args, **kwargs):
+        retry_confirm = kwargs.pop(constants.API_RETRY_CONFIRM, False)
+
         def request_with_retry_on_ssl_error(*args, **kwargs):
             try:
                 return super(TimeoutSession, self).request(*args, **kwargs)
-            except (IOError, OpenSSL.SSL.Error):
+            except (IOError, OpenSSL.SSL.Error) as err:
                 # This can happen when connection tries to access certificate
                 # file it was opened with (renegotiation?)
                 # Proper way to solve this would be to pass in-memory cert
                 # to ssl C code.
                 # Retrying here works around the problem
+
+                # IOError covered too much Exception, if resources created
+                # successfully on nsxt side but ConnectResetError happened,
+                # Retrying here will create resource twice
+                if isinstance(err, IOError) and retry_confirm:
+                    raise exceptions.RetryConfirm(msg=err)
                 return super(TimeoutSession, self).request(*args, **kwargs)
 
         def get_cert_provider():
@@ -817,7 +825,17 @@ class ClusteredAPI(object):
                         # consider endpoint inaccessible and move to next
                         # endpoint
                         endpoint.set_state(EndpointState.DOWN)
-
+                    elif exc_config.should_regenerate(e):
+                        LOG.warning("[%x] Request failed due to an exception "
+                                    "that calls for regeneration. "
+                                    "Re-generating pool.", id(conn))
+                        if bool(self.nsxlib_config.token_provider):
+                            # get new jwt token for authentication
+                            self.nsxlib_config.token_provider.get_token(
+                                refresh_token=True)
+                        # refresh endpoint with new headers
+                        # that have updated token
+                        endpoint.regenerate_pool()
                     elif not exc_config.should_retry(e):
                         LOG.info("Exception %s is configured as not retriable",
                                  e)
