@@ -599,15 +599,26 @@ class NsxLibLogicalRouter(utils.NsxLibApiBase):
                 arg_val=action,
                 arg_name='action')
 
+    def _validate_nat_rule_firewall_match(self, firewall_match):
+        if not firewall_match:
+            return
+        if firewall_match not in nsx_constants.NAT_FIREWALL_MATCH_VALUES:
+            raise exceptions.InvalidInput(
+                operation="Create/Update NAt rule",
+                arg_val=firewall_match,
+                arg_name='firewall_match')
+
     def add_nat_rule(self, logical_router_id, action, translated_network,
                      source_net=None, dest_net=None,
                      enabled=True, rule_priority=None,
                      match_ports=None, match_protocol=None,
                      match_resource_type=None,
+                     firewall_match=None,
                      bypass_firewall=True, logging=None,
                      tags=None,
                      display_name=None):
         self._validate_nat_rule_action(action)
+        self._validate_nat_rule_firewall_match(firewall_match)
         resource = 'logical-routers/%s/nat/rules' % logical_router_id
         body = {'action': action,
                 'enabled': enabled,
@@ -625,12 +636,22 @@ class NsxLibLogicalRouter(utils.NsxLibApiBase):
                 'destination_ports': match_ports,
                 'l4_protocol': match_protocol or nsx_constants.TCP}
 
-        # nat_pass parameter is supported with the router firewall feature
+        # the router firewall feature is implemented with the firewall_match
+        # paramter which has replaced nat_pass
         if (self.nsxlib and
             self.nsxlib.feature_supported(
                 nsx_constants.FEATURE_ROUTER_FIREWALL)):
-            body['nat_pass'] = bypass_firewall
-        elif not bypass_firewall:
+            # only consider bypass_firewall if firewall_match is not specified
+            if not firewall_match:
+                if bypass_firewall:
+                    body['firewall_match'] = (
+                        nsx_constants.NAT_FIREWALL_MATCH_BYPASS)
+                else:
+                    body['firewall_match'] = (
+                        nsx_constants.NAT_FIREWALL_MATCH_INTERNAL)
+            else:
+                body['firewall_match'] = firewall_match
+        elif not bypass_firewall or firewall_match:
             LOG.error("Ignoring bypass_firewall for router %s nat rule: "
                       "this feature is not supported.", logical_router_id)
         if tags is not None:
@@ -703,6 +724,8 @@ class NsxLibLogicalRouter(utils.NsxLibApiBase):
     def update_nat_rule(self, logical_router_id, nat_rule_id, **kwargs):
         if 'action' in kwargs:
             self._validate_nat_rule_action(kwargs['action'])
+        if 'firewall_match' in kwargs:
+            self._validate_nat_rule_firewall_match(kwargs['firewall_match'])
         resource = 'logical-routers/%s/nat/rules/%s' % (
             logical_router_id, nat_rule_id)
         return self._update_resource(resource, kwargs, retry=True)
