@@ -1522,6 +1522,16 @@ class IpPoolDef(ResourceDef):
     def path_defs(self):
         return (TenantDef,)
 
+    def get_obj_dict(self):
+        body = super(IpPoolDef, self).get_obj_dict()
+        self._set_attr_if_specified(body, 'ip_release_delay')
+        self._set_attr_if_supported(body, 'sync_realization')
+        return body
+
+    @property
+    def version_dependant_attr_map(self):
+        return {'sync_realization': nsx_constants.NSX_VERSION_4_1_1}
+
 
 class IpPoolAllocationDef(ResourceDef):
     '''Infra IpPoolAllocation'''
@@ -1590,6 +1600,8 @@ class IpPoolBlockSubnetDef(IpPoolSubnetDef):
         # Attrs supported from NSX 4.1.0
         self._set_attrs_if_supported(body, ['subnet_size',
                                             'allocation_range'])
+        # Attrs supported from NSX 4.1.1
+        self._set_attr_if_supported(body, 'sync_realization')
         # Attribute "subnet size" is replacement for "size" attribute
         # thus, removing redundancy
         if 'subnet_size' in body:
@@ -1598,9 +1610,11 @@ class IpPoolBlockSubnetDef(IpPoolSubnetDef):
 
     @property
     def version_dependant_attr_map(self):
-        return {'start_ip': nsx_constants.NSX_VERSION_3_0_0,
-                'subnet_size': nsx_constants.NSX_VERSION_4_1_0,
-                'allocation_range': nsx_constants.NSX_VERSION_4_1_0}
+        return {
+            'start_ip': nsx_constants.NSX_VERSION_3_0_0,
+            'subnet_size': nsx_constants.NSX_VERSION_4_1_0,
+            'allocation_range': nsx_constants.NSX_VERSION_4_1_0,
+            'sync_realization': nsx_constants.NSX_VERSION_4_1_1}
 
 
 class IpPoolStaticSubnetDef(IpPoolSubnetDef):
