@@ -79,7 +79,7 @@ class LBPoolMemberDef(object):
             body['weight'] = self.weight
         if self.admin_state:
             body['admin_state'] = self.admin_state
-        if self.backup_member:
+        if self.backup_member is not None:
             body['backup_member'] = self.backup_member
         return body
 
@@ -242,7 +242,8 @@ class LBPoolDef(ResourceDef):
         body = super(LBPoolDef, self).get_obj_dict()
         self._set_attrs_if_specified(
             body, ['active_monitor_paths',
-                   'algorithm', 'member_group', 'snat_translation'])
+                   'algorithm', 'member_group', 'snat_translation',
+                   'tcp_multiplexing_enabled', 'tcp_multiplexing_number'])
         members = self.get_attr('members')
         if members is None:
             members = []
@@ -275,6 +276,8 @@ class LBVirtualServerDef(ResourceDef):
         body = super(LBVirtualServerDef, self).get_obj_dict()
         self._set_attrs_if_specified(
             body, ['ip_address', 'ports', 'max_concurrent_connections'])
+        self._set_attrs_if_supported(
+            body, ['access_log_enabled', 'log_significant_event_only'])
         client_ssl_binding = self.get_attr('client_ssl_profile_binding')
         if client_ssl_binding:
             self._set_attr_if_specified(
@@ -343,7 +346,9 @@ class LBVirtualServerDef(ResourceDef):
 
     @property
     def version_dependant_attr_map(self):
-        return {'access_list_control': nsx_constants.NSX_VERSION_3_0_0}
+        return {'access_list_control': nsx_constants.NSX_VERSION_3_0_0,
+                'access_log_enabled': nsx_constants.NSX_VERSION_3_0_0,
+                'log_significant_event_only': nsx_constants.NSX_VERSION_3_0_0}
 
 
 class ClientSSLProfileBindingDef(object):
@@ -444,8 +449,15 @@ class LBServiceDef(ResourceDef):
 
 class LBServiceStatisticsDef(ResourceDef):
 
+    def __init__(self, **kwargs):
+        self.realtime = kwargs.pop('realtime')
+        super(LBServiceStatisticsDef, self).__init__(**kwargs)
+
     @property
     def path_pattern(self):
+        if self.realtime:
+            return (LB_SERVICES_PATH_PATTERN +
+                    '%s/statistics?source=realtime')
         return LB_SERVICES_PATH_PATTERN + '%s/statistics/'
 
     @property
