@@ -501,7 +501,7 @@ class NsxPolicyLoadBalancerPoolApi(NsxPolicyResourceBase):
                tenant=constants.POLICY_INFRA_TENANT):
         lb_pool_def = self.entry_def(
             lb_pool_id=lb_pool_id, tenant=tenant)
-        self._delete_with_retry(lb_pool_def)
+        self._delete_or_store(lb_pool_def)
 
     def get(self, lb_pool_id, tenant=constants.POLICY_INFRA_TENANT,
             silent=False):
@@ -829,7 +829,7 @@ class NsxPolicyLoadBalancerVirtualServerAPI(NsxPolicyResourceBase):
                tenant=constants.POLICY_INFRA_TENANT):
         lbvs_def = self.entry_def(
             virtual_server_id=virtual_server_id, tenant=tenant)
-        self._delete_with_retry(lbvs_def)
+        self._delete_or_store(lbvs_def)
 
     def get(self, virtual_server_id,
             tenant=constants.POLICY_INFRA_TENANT, silent=False):
