@@ -164,7 +164,7 @@ class LogicalPort(utils.NsxLibApiBase):
                switch_profile_ids=None, vif_type=None, app_id=None,
                allocate_addresses=nsx_constants.ALLOCATE_ADDRESS_NONE,
                description=None, tn_uuid=None,
-               extra_configs=None):
+               extra_configs=None, retry_confirm=False):
         tags = tags or []
         body = {'logical_switch_id': lswitch_id}
         # NOTE(arosen): If parent_vif_id is specified we need to use
@@ -181,7 +181,8 @@ class LogicalPort(utils.NsxLibApiBase):
             attachment=attachment,
             description=description,
             extra_configs=extra_configs))
-        return self.client.create(self.get_path(), body=body)
+        return self.client.create(self.get_path(), body=body,
+                                  retry_confirm=retry_confirm)
 
     def delete(self, lport_id):
         self._delete_with_retry('%s?detach=true' % lport_id)
