@@ -176,13 +176,24 @@ class RouterLib(object):
             skip_not_found=True, strict_mode=False)
 
     def add_gw_snat_rule(self, logical_router_id, gw_ip, source_net=None,
-                         bypass_firewall=True, tags=None, display_name=None):
+                         bypass_firewall=True, firewall_match=None,
+                         tags=None, display_name=None):
+        if not firewall_match:
+            return self.nsxlib.logical_router.add_nat_rule(
+                logical_router_id, action="SNAT",
+                translated_network=gw_ip,
+                source_net=source_net,
+                rule_priority=GW_NAT_PRI,
+                bypass_firewall=bypass_firewall,
+                tags=tags,
+                display_name=display_name)
+        # Ignore bypass_firewall if firewall_match is specified
         return self.nsxlib.logical_router.add_nat_rule(
             logical_router_id, action="SNAT",
             translated_network=gw_ip,
             source_net=source_net,
             rule_priority=GW_NAT_PRI,
-            bypass_firewall=bypass_firewall,
+            firewall_match=firewall_match,
             tags=tags,
             display_name=display_name)
 
@@ -224,13 +235,34 @@ class RouterLib(object):
 
     def add_fip_nat_rules(self, logical_router_id, ext_ip, int_ip,
                           match_ports=None, bypass_firewall=True,
+                          firewall_match=None,
                           tags=None, display_name=None):
+        if not firewall_match:
+            self.nsxlib.logical_router.add_nat_rule(
+                logical_router_id, action="SNAT",
+                translated_network=ext_ip,
+                source_net=int_ip,
+                rule_priority=FIP_NAT_PRI,
+                bypass_firewall=bypass_firewall,
+                tags=tags,
+                display_name=display_name)
+            self.nsxlib.logical_router.add_nat_rule(
+                logical_router_id, action="DNAT",
+                translated_network=int_ip,
+                dest_net=ext_ip,
+                rule_priority=FIP_NAT_PRI,
+                match_ports=match_ports,
+                bypass_firewall=bypass_firewall,
+                tags=tags,
+                display_name=display_name)
+            return
+        # Ignore bypass_firewall if firewall_match is specified
         self.nsxlib.logical_router.add_nat_rule(
             logical_router_id, action="SNAT",
             translated_network=ext_ip,
             source_net=int_ip,
             rule_priority=FIP_NAT_PRI,
-            bypass_firewall=bypass_firewall,
+            firewall_match=firewall_match,
             tags=tags,
             display_name=display_name)
         self.nsxlib.logical_router.add_nat_rule(
@@ -239,7 +271,7 @@ class RouterLib(object):
             dest_net=ext_ip,
             rule_priority=FIP_NAT_PRI,
             match_ports=match_ports,
-            bypass_firewall=bypass_firewall,
+            firewall_match=firewall_match,
             tags=tags,
             display_name=display_name)
 
