@@ -21,7 +21,6 @@ NSX-V3 Plugin security & Distributed Firewall integration module
 from distutils import version
 
 from oslo_log import log
-from oslo_log import versionutils
 from oslo_utils import excutils
 
 from vmware_nsxlib.v3 import exceptions
@@ -50,49 +49,16 @@ class NsxLibNsGroup(utils.NsxLibApiBase):
     def resource_type(self):
         return 'NSGroup'
 
-    def update_nsgroup_and_section(self, security_group,
+    def update_nsgroup_and_section(self, name, description, logging,
                                    nsgroup_id, section_id,
                                    log_sg_allowed_traffic):
-        name = self.get_name(security_group)
-        description = security_group['description']
-        logging = (log_sg_allowed_traffic or
-                   security_group.get(consts.LOGGING, False))
+        logging = (log_sg_allowed_traffic or logging)
         rules = self.firewall_section._process_rules_logging_for_update(
             section_id, logging)
         self.update(nsgroup_id, name, description)
         self.firewall_section.update(section_id, name, description,
                                      rules=rules)
 
-    def update_on_backend(self, context, security_group,
-                          nsgroup_id, section_id,
-                          log_sg_allowed_traffic):
-        # This api is deprecated because of the irrelevant context arg
-        versionutils.report_deprecated_feature(
-            LOG,
-            'security.NsxLibNsGroup.update_on_backend is deprecated. '
-            'Please use security.NsxLibNsGroup.update_nsgroup_and_section '
-            'instead.')
-        return self.update_nsgroup_and_section(security_group, nsgroup_id,
-                                               section_id,
-                                               log_sg_allowed_traffic)
-
-    def get_name(self, security_group):
-        # NOTE(roeyc): We add the security-group id to the NSGroup name,
-        # for usability purposes.
-        return '%(name)s - %(id)s' % security_group
-
-    def get_lport_tags(self, secgroups):
-        if len(secgroups) > utils.MAX_NSGROUPS_CRITERIA_TAGS:
-            raise exceptions.NumberOfNsgroupCriteriaTagsReached(
-                max_num=utils.MAX_NSGROUPS_CRITERIA_TAGS)
-        tags = []
-        for sg in secgroups:
-            tags = utils.add_v3_tag(tags, PORT_SG_SCOPE, sg)
-        if not tags:
-            # This port shouldn't be associated with any security-group
-            tags = [{'scope': PORT_SG_SCOPE, 'tag': None}]
-        return tags
-
     def update_lport_nsgroups(self, lport_id, original_nsgroups,
                               updated_nsgroups):
         """Update the NSgroups that the logical ports belongs to"""
@@ -119,14 +85,6 @@ class NsxLibNsGroup(utils.NsxLibApiBase):
             self.remove_member(
                 nsgroup_id, consts.TARGET_TYPE_LOGICAL_PORT, lport_id)
 
-    def update_lport(self, context, lport_id, original, updated):
-        # This api is deprecated because of the irrelevant context arg
-        versionutils.report_deprecated_feature(
-            LOG,
-            'security.NsxLibNsGroup.update_lport is deprecated. '
-            'Please use security.NsxLibNsGroup.update_lport_nsgroups instead.')
-        return self.update_lport_nsgroups(lport_id, original, updated)
-
     def get_nsservice(self, resource_type, **properties):
         service = {'resource_type': resource_type}
         service.update(properties)
@@ -243,13 +201,8 @@ class NsxLibNsGroup(utils.NsxLibApiBase):
             '%s?populate_references=true' % self.get_path(nsgroup_id))
 
     def delete(self, nsgroup_id):
-        try:
-            return self.client.delete(
-                '%s?force=true' % self.get_path(nsgroup_id))
-        # FIXME(roeyc): Should only except NotFound error.
-        except Exception:
-            LOG.debug("NSGroup %s does not exists for delete request.",
-                      nsgroup_id)
+        resource = '%s?force=true' % nsgroup_id
+        return self._delete_with_retry(resource)
 
     def find_by_display_name(self, display_name):
         found = []
@@ -454,7 +407,8 @@ class NsxLibFirewallSection(utils.NsxLibApiBase):
     def get_rule_dict(self, display_name, sources=None, destinations=None,
                       direction=consts.IN_OUT, ip_protocol=consts.IPV4_IPV6,
                       services=None, action=consts.FW_ACTION_ALLOW,
-                      logged=False, disabled=False, applied_tos=None):
+                      logged=False, disabled=False, applied_tos=None,
+                      rule_tag=None):
         rule_dict = {'display_name': display_name,
                      'direction': direction,
                      'ip_protocol': ip_protocol,
@@ -466,25 +420,35 @@ class NsxLibFirewallSection(utils.NsxLibApiBase):
                      'services': services or []}
         if applied_tos is not None:
             rule_dict['applied_tos'] = applied_tos
+        if rule_tag is not None:
+            rule_dict['rule_tag'] = rule_tag
         return rule_dict
 
     def add_rule(self, rule, section_id, operation=consts.FW_INSERT_BOTTOM):
-        resource = '%s/rules' % self.get_path(section_id)
-        params = '?operation=%s' % operation
-        if (version.LooseVersion(self.nsxlib.get_version()) >=
-            version.LooseVersion(consts.NSX_VERSION_2_4_0)):
-            rule['_revision'] = self.get(section_id)['_revision']
-        return self._create_with_retry(resource + params, rule)
+        @utils.retry_upon_exception(exceptions.StaleRevision,
+                                    max_attempts=self.client.max_attempts)
+        def _do_add_rule():
+            resource = '%s/rules' % self.get_path(section_id)
+            params = '?operation=%s' % operation
+            if (version.LooseVersion(self.nsxlib.get_version()) >=
+                version.LooseVersion(consts.NSX_VERSION_2_4_0)):
+                rule['_revision'] = self.get(section_id)['_revision']
+            return self.client.create(resource + params, rule)
+        return _do_add_rule()
 
     def add_rules(self, rules, section_id, operation=consts.FW_INSERT_BOTTOM):
-        resource = '%s/rules' % self.get_path(section_id)
-        params = '?action=create_multiple&operation=%s' % operation
-        if (version.LooseVersion(self.nsxlib.get_version()) >=
-            version.LooseVersion(consts.NSX_VERSION_2_4_0)):
-            rev_id = self.get(section_id)['_revision']
-            for rule in rules:
-                rule['_revision'] = rev_id
-        return self._create_with_retry(resource + params, {'rules': rules})
+        @utils.retry_upon_exception(exceptions.StaleRevision,
+                                    max_attempts=self.client.max_attempts)
+        def _do_add_rules():
+            resource = '%s/rules' % self.get_path(section_id)
+            params = '?action=create_multiple&operation=%s' % operation
+            if (version.LooseVersion(self.nsxlib.get_version()) >=
+                version.LooseVersion(consts.NSX_VERSION_2_4_0)):
+                rev_id = self.get(section_id)['_revision']
+                for rule in rules:
+                    rule['_revision'] = rev_id
+            return self.client.create(resource + params, {'rules': rules})
+        return _do_add_rules()
 
     def delete_rule(self, section_id, rule_id):
         resource = '%s/rules/%s' % (section_id, rule_id)
@@ -552,20 +516,6 @@ class NsxLibFirewallSection(utils.NsxLibApiBase):
             firewall_rules.append(fw_rule)
         return self.add_rules(firewall_rules, section_id)
 
-    def create_rules(self, context, section_id, nsgroup_id,
-                     logging_enabled, action, security_group_rules,
-                     ruleid_2_remote_nsgroup_map):
-        # This api is deprecated because of the irrelevant context arg
-        versionutils.report_deprecated_feature(
-            LOG,
-            'security.NsxLibFirewallSection.create_rules is deprecated. '
-            'Please use security.NsxLibFirewallSection.create_section_rules '
-            'instead.')
-        return self.create_section_rules(
-            section_id, nsgroup_id,
-            logging_enabled, action, security_group_rules,
-            ruleid_2_remote_nsgroup_map)
-
     def set_rule_logging(self, section_id, logging):
         rules = self._process_rules_logging_for_update(
             section_id, logging)
